==> oroshop-common-classes-1.7.37-20231003.145857-22.jar: com/floreantpos/model/BalanceUpdateTransaction.java <==
package com.floreantpos.model;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;

import org.apache.commons.lang.StringUtils;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.floreantpos.model.base.BaseBalanceUpdateTransaction;
import com.floreantpos.model.dao.CustomerDAO;
import com.floreantpos.util.POSUtil;
import com.google.gson.Gson;
import com.google.gson.JsonObject;

@JsonIgnoreProperties(ignoreUnknown = true, value = { "paymentType", "balanceType" })
@XmlRootElement
public class BalanceUpdateTransaction extends BaseBalanceUpdateTransaction implements TimedModel, PropertyContainer {
	private static final long serialVersionUID = 1L;

	public static final String JSON_PROP_DESCRIPTION = "description"; //$NON-NLS-1$
	public static final String JSON_PROP_BALANCE_BEFORE = "balance.before"; //$NON-NLS-1$

	public static final String PAYMENT_GATEWAY_STRIPE = "Stripe"; //$NON-NLS-1$
	public static final String PAYMENT_GATEWAY_WIRE_TRANSFER = "Wire Transfer"; //$NON-NLS-1$
	public static final String PAYMENT_GATEWAY_PAYPAL = "Paypal"; //$NON-NLS-1$

	public static final String TYPE_NEW = "New"; //$NON-NLS-1$
	public static final String TYPE_REFUND = "Refund"; //$NON-NLS-1$
	public static final String TYPE_RECURRING = "Recurring"; //$NON-NLS-1$
	public static final String TYPE_RESELLER_PAYMENT = "Reseller Payment"; //$NON-NLS-1$

	private boolean updateLastUpdateTime = true;
	private boolean updateSyncTime = false;
	private transient JsonObject propertiesContainer;
	private Customer customer;

	public boolean isUpdateSyncTime() {
		return updateSyncTime;
	}

	public void setUpdateSyncTime(boolean shouldUpdateSyncTime) {
		this.updateSyncTime = shouldUpdateSyncTime;
	}

	public boolean isUpdateLastUpdateTime() {
		return updateLastUpdateTime;
	}

	public void setUpdateLastUpdateTime(boolean shouldUpdateUpdateTime) {
		this.updateLastUpdateTime = shouldUpdateUpdateTime;
	}

	/*[CONSTRUCTOR MARKER BEGIN]*/
	public BalanceUpdateTransaction() {
	}

	/**
	 * Constructor for primary key
	 */
	public BalanceUpdateTransaction(java.lang.String id) {
		super(id);
	}

	/**
	 * Constructor for required fields
	 */
	public BalanceUpdateTransaction(java.lang.String id, java.lang.String balanceTypeString, java.lang.String paymentTypeString,
			java.lang.String transactionType, java.lang.String transactionSubType) {

		super(id, balanceTypeString, paymentTypeString, transactionType, transactionSubType);
	}

	/*[CONSTRUCTOR MARKER END]*/

	public void setPaymentType(PaymentType paymentType) {
		setPaymentTypeString(paymentType != null ? paymentType.name() : null);
	}

	@XmlTransient
	public PaymentType getPaymentType() {
		String paymentTypeString = super.getPaymentTypeString();
		if (paymentTypeString == null) {
			return null;
		}
		return PaymentType.valueOf(paymentTypeString);
	}

	public void setBalanceType(BalanceType balanceType) {
		setBalanceTypeString(balanceType != null ? balanceType.name() : null);
	}

	@XmlTransient
	public BalanceType getBalanceType() {
		String balanceTypeString = super.getBalanceTypeString();
		if (balanceTypeString == null) {
			return null;
		}
		return BalanceType.valueOf(balanceTypeString);
	}

	@Override
	public JsonObject getPropertyStore() {
		if (propertiesContainer == null) {
			propertiesContainer = new JsonObject();
		}
		return propertiesContainer;
	}

	@Override
	public String getExtraProperties() {
		if (propertiesContainer != null) {
			return propertiesContainer.toString();
		}

		String properties = super.getExtraProperties();
		if (StringUtils.isEmpty(properties)) {
			return null;
		}

		propertiesContainer = new Gson().fromJson(properties, JsonObject.class);
		return properties;
	}

	@Override
	public void setExtraProperties(String properties) {
		super.setExtraProperties(properties);
		propertiesContainer = new Gson().fromJson(properties, JsonObject.class);
	}

	public String getDescription() {
		return getProperty(JSON_PROP_DESCRIPTION);
	}

	public void setDescription(String details) {
		addProperty(JSON_PROP_DESCRIPTION, details);
	}

	public Double getBalanceBefore() {
		return POSUtil.parseDouble(getProperty(JSON_PROP_BALANCE_BEFORE));
	}

	public void setBalanceBefore(double amount) {
		addProperty(JSON_PROP_BALANCE_BEFORE, String.valueOf(amount));
	}

	@XmlTransient
	@JsonIgnore
	public Customer getCustomer() {
		if (customer != null) {
			return customer;
		}
		if (StringUtils.isBlank(super.getAccountNumber())) {
			return null;
		}
		return customer = CustomerDAO.getInstance().get(super.getAccountNumber());
	}

	public void setCustomer(Customer customer) {
		this.customer = customer;
	}

	public String getType() {
		return getProperty("type"); //$NON-NLS-1$
	}

	public void setType(String type) {
		addProperty("type", type); //$NON-NLS-1$
	}

}

==> oroshop-common-classes-1.9-20250916.183155-26.jar: com/floreantpos/model/BalanceUpdateTransaction.java <==
package com.floreantpos.model;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;

import org.apache.commons.lang.StringUtils;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.floreantpos.model.base.BaseBalanceUpdateTransaction;
import com.floreantpos.model.dao.CustomerDAO;
import com.floreantpos.util.POSUtil;
import com.google.gson.Gson;
import com.google.gson.JsonObject;

@JsonIgnoreProperties(ignoreUnknown = true, value = { "paymentType", "balanceType" })
@XmlRootElement
public class BalanceUpdateTransaction extends BaseBalanceUpdateTransaction implements TimedModel, PropertyContainer {
	private static final long serialVersionUID = 1L;

	public static final String JSON_PROP_DESCRIPTION = "description"; //$NON-NLS-1$
	public static final String JSON_PROP_BALANCE_BEFORE = "balance.before"; //$NON-NLS-1$

	public static final String PAYMENT_GATEWAY_STRIPE = "Stripe"; //$NON-NLS-1$
	public static final String PAYMENT_GATEWAY_WIRE_TRANSFER = "Wire Transfer"; //$NON-NLS-1$
	public static final String PAYMENT_GATEWAY_PAYPAL = "PayPal"; //$NON-NLS-1$

	public static final String TYPE_NEW = "New"; //$NON-NLS-1$
	public static final String TYPE_REFUND = "Refund"; //$NON-NLS-1$
	public static final String TYPE_RECURRING = "Recurring"; //$NON-NLS-1$
	public static final String TYPE_RESELLER_PAYMENT = "Reseller Payment"; //$NON-NLS-1$

	private boolean updateLastUpdateTime = true;
	private boolean updateSyncTime = false;
	private transient JsonObject propertiesContainer;
	private Customer customer;

	public boolean isUpdateSyncTime() {
		return updateSyncTime;
	}

	public void setUpdateSyncTime(boolean shouldUpdateSyncTime) {
		this.updateSyncTime = shouldUpdateSyncTime;
	}

	public boolean isUpdateLastUpdateTime() {
		return updateLastUpdateTime;
	}

	public void setUpdateLastUpdateTime(boolean shouldUpdateUpdateTime) {
		this.updateLastUpdateTime = shouldUpdateUpdateTime;
	}

	/*[CONSTRUCTOR MARKER BEGIN]*/
	public BalanceUpdateTransaction() {
	}

	/**
	 * Constructor for primary key
	 */
	public BalanceUpdateTransaction(java.lang.String id) {
		super(id);
	}

	/**
	 * Constructor for required fields
	 */
	public BalanceUpdateTransaction(java.lang.String id, java.lang.String balanceTypeString, java.lang.String paymentTypeString,
			java.lang.String transactionType, java.lang.String transactionSubType) {

		super(id, balanceTypeString, paymentTypeString, transactionType, transactionSubType);
	}

	/*[CONSTRUCTOR MARKER END]*/

	public void setPaymentType(PaymentType paymentType) {
		setPaymentTypeString(paymentType != null ? paymentType.name() : null);
	}

	@XmlTransient
	public PaymentType getPaymentType() {
		String paymentTypeString = super.getPaymentTypeString();
		if (paymentTypeString == null) {
			return null;
		}
		return PaymentType.valueOf(paymentTypeString);
	}

	public void setBalanceType(BalanceType balanceType) {
		setBalanceTypeString(balanceType != null ? balanceType.name() : null);
	}

	@XmlTransient
	public BalanceType getBalanceType() {
		String balanceTypeString = super.getBalanceTypeString();
		if (balanceTypeString == null) {
			return null;
		}
		return BalanceType.valueOf(balanceTypeString);
	}

	@Override
	public JsonObject getPropertyStore() {
		if (propertiesContainer == null) {
			propertiesContainer = new JsonObject();
		}
		return propertiesContainer;
	}

	@Override
	public String getExtraProperties() {
		if (propertiesContainer != null) {
			return propertiesContainer.toString();
		}

		String properties = super.getExtraProperties();
		if (StringUtils.isEmpty(properties)) {
			return null;
		}

		propertiesContainer = new Gson().fromJson(properties, JsonObject.class);
		return properties;
	}

	@Override
	public void setExtraProperties(String properties) {
		super.setExtraProperties(properties);
		propertiesContainer = new Gson().fromJson(properties, JsonObject.class);
	}

	public String getDescription() {
		return getProperty(JSON_PROP_DESCRIPTION);
	}

	public void setDescription(String details) {
		addProperty(JSON_PROP_DESCRIPTION, details);
	}

	public Double getBalanceBefore() {
		return POSUtil.parseDouble(getProperty(JSON_PROP_BALANCE_BEFORE));
	}

	public void setBalanceBefore(double amount) {
		addProperty(JSON_PROP_BALANCE_BEFORE, String.valueOf(amount));
	}

	@XmlTransient
	@JsonIgnore
	public Customer getCustomer() {
		if (customer != null) {
			return customer;
		}
		if (StringUtils.isBlank(super.getAccountNumber())) {
			return null;
		}
		return customer = CustomerDAO.getInstance().get(super.getAccountNumber());
	}

	public void setCustomer(Customer customer) {
		this.customer = customer;
	}

	public String getType() {
		return getProperty("type"); //$NON-NLS-1$
	}

	public void setType(String type) {
		addProperty("type", type); //$NON-NLS-1$
	}

}
